[![AITool logo](https://raw.githubusercontent.com/deepgameai/aitool/main/docs/logo/logo.png)](https://deepgameai.github.io/2020-02-28-test-markdown/)

--------------------------------------------------------------------------------

[![version](https://badgen.net/badge/version/0.0.1/blue)](https://aitool20201028.readthedocs.io/en/latest/)
[![stars](https://img.shields.io/github/stars/deepgameai/aitool?style=social)]()

AITool is a Python package that provides two high-level features:
- 封装了有百种算法（包括动态规划、统计模型、深度学习等等）
- 每种算法都自带数据，便于验证和使用
- Encapsulates hundreds of algorithms. (Including dynamic programming, statistical models, deep learning, etc.)
- Each algorithm comes with its own data for easy verification and use.

aitool - 
[官方主页](https://deepgameai.github.io/2020-02-28-test-markdown/) - 
[文档](https://aitool20201028.readthedocs.io/en/latest/)

- [Motivation](#motivation)
- [Installation](#installation)
- [Getting Started](#getting-started)
- [Communication](#communication)
- [Releases and Contributing](#releases-and-contributing)
- [The Team](#the-team)

## Motivation

## Installation

## Getting Started

## Communication

## Releases and Contributing

## The Team

## 授权许可
本项目采用 MIT 开源授权许可证，完整的授权说明已放置在 [LICENSE](LICENSE) 文件中。